@@ -6,8 +6,8 @@
 #' 4 (rook's case) or 8 (queen's case). The default is 4.
 #' @param classes A vector or a list with the values of selected classes from the `x` object.
 #' It is used to calculate wecoma only for selected classes.
-#' @param fun "mean", "geometric_mean", or "focal". The default is "mean".
-#' @param na_action "replace", "omit", or "keep". The default is "replace".
+#' @param fun Function to calculate values from adjacent cells to contribute to output matrix, `"mean"` - calculate average values from adjacent cells of weight matrix, `"geometric_mean"` - calculate geometric mean values from adjacent cells of weight matrix, or `"focal"` assign value from the focal cell.
+#' @param na_action Decides on how to behave in the presence of missing values in `w`. Possible options are `"replace"`, `"omit"`, `"keep"`. The default, `"replace"`, replaces missing values with 0, `"omit"` does not use cells with missing values, and `"keep"` keeps missing values.
 #'
 #' @return A weighted co-occurrence matrix
 #' @export
@@ -26,7 +26,7 @@ get_wecoma = function(x, w, neighbourhood = 4, classes = NULL, fun = "mean", na_
   if (is.null(classes)){
     classes = get_unique_values(x, TRUE)
   }
-  if (inherits(classes, "integer")){
+  if (inherits(classes, c("integer", "numeric"))){
     classes = list(classes)
   }
 
